;                     Configure the 2000F System Processor.
;
;
; This include file configures the CPU and I/O card cage in the System Processor
; to contain the necessary device interfaces in the proper card slots.  It is
; invoked by the SP command files, as follows:
;
;    do spconfig.inc <cpu-model> <disc-model> [ <drum-model> ]
;
; ...where <cpu-model> and <disc-model> are the models of the CPU (2100 or
; 21MX) and disc (7900 or 2883) to use.  If <drum-model> is present, it will be
; "2766", as that is the only drum model supported.  This file is never invoked
; directly by the user.
;
; These device assignments are listed in the "Time-Shared BASIC/2000, Level F
; System Operator's Manual" (HP part number 02000-90074, November 1974):
;
;      Base    Option
;     Select   Select
;      Code     Code   Device
;     ------   ------  ----------------------------------------------------
;     10-11    10-11   12875A Processor Interconnect
;       12       12    12531C Buffered Teleprinter Interface
;       13       13    12597A-002 Tape Reader Interface
;       -      14-15   12610B Drum Memory Interface
;       14       16    12539C Time Base Generator Interface
;     15-16    17-20   13210A Disc Drive Interface or 12565A Disc Interface
;     17-20      -     12777A Priority Jumper Card (installed by default)
;     21-22    21-22   13183B Digital Magnetic Tape Unit Interface
;
; The "Base" select codes are used when the system does not host a drum, and
; the "Option" select codes are used when a drum is used.  The Priority Jumper
; cards permit invariant select codes for the magnetic tape interface.


; Configure the System Processor CPU.
;
; The SP requires floating-point support, which must be enabled specifically
; for 2100 CPUs (floating-point is standard on the 21MX series).

set CPU %1,32K

if "%1" == "2100" set CPU FP


; Configure and assign the select codes of the required devices.

set IPL SC=10,ENABLED
set TTY SC=12
set PTR SC=13,ENABLED
set TBG SC=14,ENABLED
set MSD SC=21,ENABLED


; Configure the tape drive interface model.

set MSC 13183


; Configure and assign the select code of the disc device.

if "%2" == "7900" set DPD SC=15,ENABLED ; set DQD DISABLED ; set DPC 13210
if "%2" == "2883" set DQD SC=15,ENABLED ; set DPD DISABLED


; If the drum is specified, reconfigure the select codes to insert the drum
; interface cards.

if "%3" == "" set DRD SC=14,DISABLED

if "%3" != "" set DRD SC=14,ENABLED ; set DRC 512K ; set TBG SC=16
if "%3" != "" if "%2" == "7900" set DPD SC=17
if "%3" != "" if "%2" == "2883" set DQD SC=17


; Disable the devices that will not be used with this system.

set BACI DISABLED
set LPS  DISABLED
set LPT  DISABLED
set MPX  DISABLED
set PTP  DISABLED
set DA   DISABLED
set DS   DISABLED
set MTD  DISABLED
set PIF  DISABLED
